@@ -1,7 +1,7 @@
-# texttable - module for creating simple ASCII tables
-# Copyright (C) 2003-2020 Gerome Fournier <jef(at)foutaise.org>
+# texttable - module to create simple ASCII tables
+# Copyright (C) 2003-2022 Gerome Fournier <jef(at)foutaise.org>
 
-"""module for creating simple ASCII tables
+"""module to create simple ASCII tables
 
 
 Example:
@@ -63,7 +63,7 @@ __all__ = ["Texttable", "ArraySizeError"]
 
 __author__ = 'Gerome Fournier <jef(at)foutaise.org>'
 __license__ = 'MIT'
-__version__ = '1.6.4'
+__version__ = '1.6.5'
 __credits__ = """\
 Jeff Kowalczyk:
     - textwrap improved import
